# SPDX-FileCopyrightText: 2021 ladyada for Adafruit Industries
# SPDX-License-Identifier: MIT

"""
'sine_demo.py'.

=================================================
toggles the builtin LED using a sine wave
"""
import time
import board
import digitalio
from adafruit_waveform import sine

LED = digitalio.DigitalInOut(board.D13)
LED.switch_to_output()

SINE_SAMPLE = sine.sine_wave(150, 50)

while True:
    for i in range(len(SINE_SAMPLE)):
        LED.value = i
        print(LED.value)
        time.sleep(0.50)



# SPDX-FileCopyrightText: 2017 Scott Shawcroft for Adafruit Industries
#
# SPDX-License-Identifier: MIT

"""
`adafruit_waveform.square`
====================================================

This library generates squard waveforms that can be used to generate
squard audio signals.

* Author(s): Scott Shawcroft, BrentRu
"""

import array

__version__ = "1.3.17"
__repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_Waveform.git"


def square_wave(sample_length: int = 2):
    """Generate a single square wave of sample_length size"""
    square = array.array("H", [0] * sample_length)
    for i in range(sample_length // 2):
        square[i] = 0xFFFF
    return square



# SPDX-FileCopyrightText: 2021 ladyada for Adafruit Industries
# SPDX-License-Identifier: MIT

"""
'square_demo.py'.

=================================================
toggles the builtin LED using a square wave
"""
import time
import digitalio
import board
from adafruit_waveform import square

LED = digitalio.DigitalInOut(board.D13)
LED.switch_to_output()
SAMPLE_SQUARE = square.square_wave(2)

while True:
    for i in range(len(SAMPLE_SQUARE)):
        LED.value = i
        print(LED.value)
        time.sleep(0.5)



# SPDX-FileCopyrightText: 2017 Scott Shawcroft for Adafruit Industries
#
# SPDX-License-Identifier: MIT

"""
`adafruit_waveform.sine`
====================================================

This library generates sine waveforms that can be used to generate
sine audio signals.

* Author(s): Scott Shawcroft
"""

import array
import math

__version__ = "1.3.17"
__repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_Waveform.git"


def sine_wave(sample_frequency: float, pitch: float):
    """Generate a single sine wav cycle at the given sampling frequency and pitch."""
    length = int(sample_frequency / pitch)
    b = array.array("H", [0] * length)
    for i in range(length):
        b[i] = int(math.sin(math.pi * 2 * i / length) * ((2**15) - 1) + 2**15)
    return b
